@@ -16,23 +16,22 @@ def test_read_acqknowledge():
     df, sampling_rate = nk.read_acqknowledge(os.path.join(path_data, "acqnowledge.acq"), sampling_rate=2000)
     assert sampling_rate == 2000
 
-    df, sampling_rate = nk.read_acqknowledge(os.path.join(path_data, "acqnowledge.acq"), sampling_rate='max')
+    df, sampling_rate = nk.read_acqknowledge(os.path.join(path_data, "acqnowledge.acq"), sampling_rate="max")
     assert sampling_rate == 4000
 
+
 def test_data():
 
-    dataset="bio_eventrelated_100hz"
+    dataset = "bio_eventrelated_100hz"
 
     data = nk.data(dataset)
     assert len(data.columns) == 4
-    assert data.size == 15000*4
-    assert all(elem in ['ECG', 'EDA', 'Photosensor', 'RSP']
-               for elem in np.array(data.columns.values, dtype=str))
+    assert data.size == 15000 * 4
+    assert all(elem in ["ECG", "EDA", "Photosensor", "RSP"] for elem in np.array(data.columns.values, dtype=str))
 
-    dataset2="bio_eventrelated_100hz.csv"
+    dataset2 = "bio_eventrelated_100hz.csv"
 
     data2 = nk.data(dataset2)
     assert len(data.columns) == len(data2.columns)
     assert data2.size == data.size
-    assert all(elem in np.array(data.columns.values, dtype=str)
-               for elem in np.array(data2.columns.values, dtype=str))
+    assert all(elem in np.array(data.columns.values, dtype=str) for elem in np.array(data2.columns.values, dtype=str))
