@@ -250,20 +250,24 @@ def test_ecg_intervalrelated():
     data = nk.data("bio_resting_5min_100hz")
     df, info = nk.ecg_process(data["ECG"], sampling_rate=100)
 
-    columns = ['ECG_Rate_Mean', 'HRV_RMSSD', 'HRV_MeanNN', 'HRV_SDNN', 'HRV_SDSD',
-       'HRV_CVNN', 'HRV_CVSD', 'HRV_MedianNN', 'HRV_MadNN', 'HRV_MCVNN',
-       'HRV_IQRNN', 'HRV_pNN50', 'HRV_pNN20', 'HRV_TINN', 'HRV_HTI',
-       'HRV_ULF', 'HRV_VLF', 'HRV_LF', 'HRV_HF', 'HRV_VHF', 'HRV_LFHF',
-       'HRV_LFn', 'HRV_HFn', 'HRV_LnHF', 'HRV_SD1', 'HRV_SD2',
-       'HRV_SD1SD2', 'HRV_S', 'HRV_CSI', 'HRV_CVI', 'HRV_CSI_Modified',
-       'HRV_PIP', 'HRV_IALS', 'HRV_PSS', 'HRV_PAS', 'HRV_ApEn',
-       'HRV_SampEn', 'HRV_MSE', 'HRV_CMSE', 'HRV_RCMSE', 'HRV_GI', 'HRV_SI', 'HRV_AI', 'HRV_PI',
-       'HRV_C1d', 'HRV_C1a', 'HRV_SD1d',
-       'HRV_SD1a', 'HRV_C2d',
-       'HRV_C2a', 'HRV_SD2d', 'HRV_SD2a',
-       'HRV_Cd', 'HRV_Ca', 'HRV_SDNNd',
-       'HRV_SDNNa', 'HRV_ApEn', 'HRV_SampEn', 'HRV_MSE',
-       'HRV_CMSE', 'HRV_RCMSE', 'HRV_DFA', 'HRV_CorrDim']
+    columns = [
+        'ECG_Rate_Mean', 'HRV_RMSSD', 'HRV_MeanNN', 'HRV_SDNN', 'HRV_SDSD',
+        'HRV_CVNN', 'HRV_CVSD', 'HRV_MedianNN', 'HRV_MadNN', 'HRV_MCVNN',
+        'HRV_IQRNN', 'HRV_pNN50', 'HRV_pNN20', 'HRV_TINN', 'HRV_HTI',
+        'HRV_ULF', 'HRV_VLF', 'HRV_LF', 'HRV_HF', 'HRV_VHF', 'HRV_LFHF',
+        'HRV_LFn', 'HRV_HFn', 'HRV_LnHF', 'HRV_SD1', 'HRV_SD2',
+        'HRV_SD1SD2', 'HRV_S', 'HRV_CSI', 'HRV_CVI', 'HRV_CSI_Modified',
+        'HRV_PIP', 'HRV_IALS', 'HRV_PSS', 'HRV_PAS', 'HRV_GI', 'HRV_SI',
+        'HRV_AI', 'HRV_PI', 'HRV_C1d', 'HRV_C1a', 'HRV_SD1d', 'HRV_SD1a',
+        'HRV_C2d', 'HRV_C2a', 'HRV_SD2d', 'HRV_SD2a', 'HRV_Cd', 'HRV_Ca',
+        'HRV_SDNNd', 'HRV_SDNNa', 'HRV_DFA_alpha1',
+        'HRV_DFA_alpha1_ExpRange', 'HRV_DFA_alpha1_ExpMean',
+        'HRV_DFA_alpha1_DimRange', 'HRV_DFA_alpha1_DimMean',
+        'HRV_DFA_alpha2', 'HRV_DFA_alpha2_ExpRange',
+        'HRV_DFA_alpha2_ExpMean', 'HRV_DFA_alpha2_DimRange',
+        'HRV_DFA_alpha2_DimMean', 'HRV_ApEn', 'HRV_SampEn', 'HRV_MSE',
+        'HRV_CMSE', 'HRV_RCMSE', 'HRV_CD'
+        ]
 
     # Test with signal dataframe
     features_df = nk.ecg_intervalrelated(df, sampling_rate=100)
@@ -271,8 +275,7 @@ def test_ecg_intervalrelated():
     # https://github.com/neuropsychology/NeuroKit/issues/304
     assert all(features_df == nk.ecg_analyze(df, sampling_rate=100, method="interval-related"))
 
-    assert all(elem in np.array(features_df.columns.values, dtype=str) for elem
-               in columns)
+    assert (elem in columns for elem in np.array(features_df.columns.values, dtype=str))
     assert features_df.shape[0] == 1  # Number of rows
 
     # Test with dict
@@ -281,6 +284,5 @@ def test_ecg_intervalrelated():
                               sampling_rate=100, epochs_end=150)
     features_dict = nk.ecg_intervalrelated(epochs, sampling_rate=100)
 
-    assert all(elem in columns for elem
-               in np.array(features_dict.columns.values, dtype=str))
+    assert (elem in columns for elem in np.array(features_dict.columns.values, dtype=str))
     assert features_dict.shape[0] == 2  # Number of rows
